package com.game.business.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.game.business.domain.AppGameCommission;

/**
 * 游戏佣金配置Mapper接口
 *
 * @author game
 * @date 2024-06-23
 */
public interface AppGameCommissionMapper extends BaseMapper<AppGameCommission> {
    /**
     * 查询游戏佣金配置
     *
     * @param id 游戏佣金配置主键
     * @return 游戏佣金配置
     */
    public AppGameCommission selectAppGameCommissionById(Long id);

    /**
     * 查询游戏佣金配置列表
     *
     * @param appGameCommission 游戏佣金配置
     * @return 游戏佣金配置集合
     */
    public List<AppGameCommission> selectAppGameCommissionList(AppGameCommission appGameCommission);

    /**
     * 新增游戏佣金配置
     *
     * @param appGameCommission 游戏佣金配置
     * @return 结果
     */
    public int insertAppGameCommission(AppGameCommission appGameCommission);

    /**
     * 修改游戏佣金配置
     *
     * @param appGameCommission 游戏佣金配置
     * @return 结果
     */
    public int updateAppGameCommission(AppGameCommission appGameCommission);

    /**
     * 删除游戏佣金配置
     *
     * @param id 游戏佣金配置主键
     * @return 结果
     */
    public int deleteAppGameCommissionById(Long id);

    /**
     * 批量删除游戏佣金配置
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppGameCommissionByIds(Long[] ids);
}